==> daal-devel-2018.0.0.20170814-0.tar.bz2: pydaal_sources/daal/algorithms/neural_networks/initializers/xavier.py <==
# Copyright 2014-2017 Intel Corporation
# All Rights Reserved.
#
# If this  software was obtained  under the  Intel Simplified  Software License,
# the following terms apply:
#
# The source code,  information  and material  ("Material") contained  herein is
# owned by Intel Corporation or its  suppliers or licensors,  and  title to such
# Material remains with Intel  Corporation or its  suppliers or  licensors.  The
# Material  contains  proprietary  information  of  Intel or  its suppliers  and
# licensors.  The Material is protected by  worldwide copyright  laws and treaty
# provisions.  No part  of  the  Material   may  be  used,  copied,  reproduced,
# modified, published,  uploaded, posted, transmitted,  distributed or disclosed
# in any way without Intel's prior express written permission.  No license under
# any patent,  copyright or other  intellectual property rights  in the Material
# is granted to  or  conferred  upon  you,  either   expressly,  by implication,
# inducement,  estoppel  or  otherwise.  Any  license   under such  intellectual
# property rights must be express and approved by Intel in writing.
#
# Unless otherwise agreed by Intel in writing,  you may not remove or alter this
# notice or  any  other  notice   embedded  in  Materials  by  Intel  or Intel's
# suppliers or licensors in any way.
#
#
# If this  software  was obtained  under the  Apache License,  Version  2.0 (the
# "License"), the following terms apply:
#
# You may  not use this  file except  in compliance  with  the License.  You may
# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless  required  by   applicable  law  or  agreed  to  in  writing,  software
# distributed under the License  is distributed  on an  "AS IS"  BASIS,  WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the   License  for the   specific  language   governing   permissions  and
# limitations under the License.


from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_xavier', [dirname(__file__)])
        except ImportError:
            import _xavier
            return _xavier
        if fp is not None:
            try:
                _mod = imp.load_module('_xavier', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _xavier = swig_import_helper()
    del swig_import_helper
else:
    import _xavier
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


import daal.algorithms.neural_networks.initializers
import daal.algorithms.neural_networks
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.data_feature_utils
import daal.algorithms.neural_networks.layers.backward
import daal.algorithms.neural_networks.layers
import daal.algorithms.neural_networks.layers.forward
import daal.algorithms.engines.mt19937
import daal.algorithms.engines

_xavier.defaultDense_swigconstant(_xavier)
defaultDense = _xavier.defaultDense
class Parameter(daal.algorithms.neural_networks.initializers.Parameter):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.Parameter]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Parameter, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.Parameter]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Parameter, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _xavier.new_Parameter(*args)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_setmethods__["seed"] = _xavier.Parameter_seed_set
    __swig_getmethods__["seed"] = _xavier.Parameter_seed_get
    if _newclass:
        seed = _swig_property(_xavier.Parameter_seed_get, _xavier.Parameter_seed_set)

    def check(self):
        return _xavier.Parameter_check(self)
    __swig_destroy__ = _xavier.delete_Parameter
    __del__ = lambda self: None
Parameter_swigregister = _xavier.Parameter_swigregister
Parameter_swigregister(Parameter)

class Batch_Float64DefaultDense(daal.algorithms.neural_networks.initializers.InitializerIface):
    r"""
This class is an alias of Batch(fptype=float64, method=daal.algorithms.neural_networks.initializers.xavier.defaultDense)
    """
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.InitializerIface]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch_Float64DefaultDense, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.InitializerIface]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch_Float64DefaultDense, name)
    __repr__ = _swig_repr
    __swig_setmethods__["parameter"] = _xavier.Batch_Float64DefaultDense_parameter_set
    __swig_getmethods__["parameter"] = _xavier.Batch_Float64DefaultDense_parameter_get
    if _newclass:
        parameter = _swig_property(_xavier.Batch_Float64DefaultDense_parameter_get, _xavier.Batch_Float64DefaultDense_parameter_set)

    def __init__(self, *args):
        this = _xavier.new_Batch_Float64DefaultDense(*args)
        try:
            self.this.append(this)
        except:
            self.this = this

    def getMethod(self):
        return _xavier.Batch_Float64DefaultDense_getMethod(self)

    def getParameter(self):
        return _xavier.Batch_Float64DefaultDense_getParameter(self)

    def getResult(self):
        return _xavier.Batch_Float64DefaultDense_getResult(self)

    def setResult(self, result):
        return _xavier.Batch_Float64DefaultDense_setResult(self, result)

    def clone(self):
        return _xavier.Batch_Float64DefaultDense_clone(self)

    def allocateResult(self):
        return _xavier.Batch_Float64DefaultDense_allocateResult(self)

    def compute(self):
        return _xavier.Batch_Float64DefaultDense_compute(self)
    __swig_destroy__ = _xavier.delete_Batch_Float64DefaultDense
    __del__ = lambda self: None
Batch_Float64DefaultDense_swigregister = _xavier.Batch_Float64DefaultDense_swigregister
Batch_Float64DefaultDense_swigregister(Batch_Float64DefaultDense)

class Batch_Float32DefaultDense(daal.algorithms.neural_networks.initializers.InitializerIface):
    r"""
This class is an alias of Batch(fptype=float32, method=daal.algorithms.neural_networks.initializers.xavier.defaultDense)
    """
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.InitializerIface]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch_Float32DefaultDense, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.InitializerIface]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch_Float32DefaultDense, name)
    __repr__ = _swig_repr
    __swig_setmethods__["parameter"] = _xavier.Batch_Float32DefaultDense_parameter_set
    __swig_getmethods__["parameter"] = _xavier.Batch_Float32DefaultDense_parameter_get
    if _newclass:
        parameter = _swig_property(_xavier.Batch_Float32DefaultDense_parameter_get, _xavier.Batch_Float32DefaultDense_parameter_set)

    def __init__(self, *args):
        this = _xavier.new_Batch_Float32DefaultDense(*args)
        try:
            self.this.append(this)
        except:
            self.this = this

    def getMethod(self):
        return _xavier.Batch_Float32DefaultDense_getMethod(self)

    def getParameter(self):
        return _xavier.Batch_Float32DefaultDense_getParameter(self)

    def getResult(self):
        return _xavier.Batch_Float32DefaultDense_getResult(self)

    def setResult(self, result):
        return _xavier.Batch_Float32DefaultDense_setResult(self, result)

    def clone(self):
        return _xavier.Batch_Float32DefaultDense_clone(self)

    def allocateResult(self):
        return _xavier.Batch_Float32DefaultDense_allocateResult(self)

    def compute(self):
        return _xavier.Batch_Float32DefaultDense_compute(self)
    __swig_destroy__ = _xavier.delete_Batch_Float32DefaultDense
    __del__ = lambda self: None
Batch_Float32DefaultDense_swigregister = _xavier.Batch_Float32DefaultDense_swigregister
Batch_Float32DefaultDense_swigregister(Batch_Float32DefaultDense)

from numpy import float64, float32, intc

class Batch(object):
    r"""Factory class for different types of Batch."""
    def __new__(cls,
                *args, **kwargs):
        if 'fptype' in kwargs and kwargs['fptype'] == float64:
            if 'method' not in kwargs or kwargs['method'] == defaultDense:
                return Batch_Float64DefaultDense(*args)
        if 'fptype' not in kwargs or kwargs['fptype'] == float32:
            if 'method' not in kwargs or kwargs['method'] == defaultDense:
                return Batch_Float32DefaultDense(*args)

        raise RuntimeError("No appropriate constructor found for Batch")


# This file is compatible with both classic and new-style classes.

==> daal-devel-2020.0-166.tar.bz2: pydaal_sources/daal/algorithms/neural_networks/initializers/xavier.py <==
# Copyright 2014-2019 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.



from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_xavier_', [dirname(__file__)])
        except ImportError:
            import _xavier_
            return _xavier_
        if fp is not None:
            try:
                _mod = imp.load_module('_xavier_', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _xavier_ = swig_import_helper()
    del swig_import_helper
else:
    import _xavier_
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


try:
    import weakref
    weakref_proxy = weakref.proxy
except:
    weakref_proxy = lambda x: x


import daal.algorithms.neural_networks.initializers
import daal.algorithms.neural_networks
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.features
import daal.data_management.modifiers.csv
import daal.data_management.modifiers
import daal.algorithms.neural_networks.layers.backward
import daal.algorithms.neural_networks.layers
import daal.algorithms.neural_networks.layers.forward
import daal.algorithms.engines.mt19937
import daal.algorithms.engines

_xavier_.defaultDense_swigconstant(_xavier_)
defaultDense = _xavier_.defaultDense
class Parameter(daal.algorithms.neural_networks.initializers.Parameter):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.Parameter]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Parameter, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.Parameter]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Parameter, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _xavier_.new_Parameter(*args)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_setmethods__["seed"] = _xavier_.Parameter_seed_set
    __swig_getmethods__["seed"] = _xavier_.Parameter_seed_get
    if _newclass:
        seed = _swig_property(_xavier_.Parameter_seed_get, _xavier_.Parameter_seed_set)

    def check(self):
        return _xavier_.Parameter_check(self)
    __swig_destroy__ = _xavier_.delete_Parameter
    __del__ = lambda self: None
Parameter_swigregister = _xavier_.Parameter_swigregister
Parameter_swigregister(Parameter)

class Batch_Float64DefaultDense(daal.algorithms.neural_networks.initializers.InitializerIface):
    r"""
    This class is an alias of Batch()
    """
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.InitializerIface]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch_Float64DefaultDense, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.InitializerIface]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch_Float64DefaultDense, name)
    __repr__ = _swig_repr
    __swig_setmethods__["parameter"] = _xavier_.Batch_Float64DefaultDense_parameter_set
    __swig_getmethods__["parameter"] = _xavier_.Batch_Float64DefaultDense_parameter_get
    if _newclass:
        parameter = _swig_property(_xavier_.Batch_Float64DefaultDense_parameter_get, _xavier_.Batch_Float64DefaultDense_parameter_set)

    def __init__(self, *args):
        this = _xavier_.new_Batch_Float64DefaultDense(*args)
        try:
            self.this.append(this)
        except:
            self.this = this

    def getMethod(self):
        return _xavier_.Batch_Float64DefaultDense_getMethod(self)

    def getParameter(self):
        return _xavier_.Batch_Float64DefaultDense_getParameter(self)

    def getResult(self):
        return _xavier_.Batch_Float64DefaultDense_getResult(self)

    def setResult(self, result):
        return _xavier_.Batch_Float64DefaultDense_setResult(self, result)

    def clone(self):
        return _xavier_.Batch_Float64DefaultDense_clone(self)

    def allocateResult(self):
        return _xavier_.Batch_Float64DefaultDense_allocateResult(self)

    def compute(self):
        return _xavier_.Batch_Float64DefaultDense_compute(self)
    __swig_destroy__ = _xavier_.delete_Batch_Float64DefaultDense
    __del__ = lambda self: None
Batch_Float64DefaultDense_swigregister = _xavier_.Batch_Float64DefaultDense_swigregister
Batch_Float64DefaultDense_swigregister(Batch_Float64DefaultDense)

class Batch_Float32DefaultDense(daal.algorithms.neural_networks.initializers.InitializerIface):
    r"""
    This class is an alias of Batch()
    """
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.InitializerIface]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch_Float32DefaultDense, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.neural_networks.initializers.InitializerIface]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch_Float32DefaultDense, name)
    __repr__ = _swig_repr
    __swig_setmethods__["parameter"] = _xavier_.Batch_Float32DefaultDense_parameter_set
    __swig_getmethods__["parameter"] = _xavier_.Batch_Float32DefaultDense_parameter_get
    if _newclass:
        parameter = _swig_property(_xavier_.Batch_Float32DefaultDense_parameter_get, _xavier_.Batch_Float32DefaultDense_parameter_set)

    def __init__(self, *args):
        this = _xavier_.new_Batch_Float32DefaultDense(*args)
        try:
            self.this.append(this)
        except:
            self.this = this

    def getMethod(self):
        return _xavier_.Batch_Float32DefaultDense_getMethod(self)

    def getParameter(self):
        return _xavier_.Batch_Float32DefaultDense_getParameter(self)

    def getResult(self):
        return _xavier_.Batch_Float32DefaultDense_getResult(self)

    def setResult(self, result):
        return _xavier_.Batch_Float32DefaultDense_setResult(self, result)

    def clone(self):
        return _xavier_.Batch_Float32DefaultDense_clone(self)

    def allocateResult(self):
        return _xavier_.Batch_Float32DefaultDense_allocateResult(self)

    def compute(self):
        return _xavier_.Batch_Float32DefaultDense_compute(self)
    __swig_destroy__ = _xavier_.delete_Batch_Float32DefaultDense
    __del__ = lambda self: None
Batch_Float32DefaultDense_swigregister = _xavier_.Batch_Float32DefaultDense_swigregister
Batch_Float32DefaultDense_swigregister(Batch_Float32DefaultDense)

from numpy import float64, float32, intc

class Batch(object):
    r"""Factory class for different types of Batch."""
    def __new__(cls,
                *args, **kwargs):
        if 'fptype' in kwargs and kwargs['fptype'] == float64:
            if 'method' not in kwargs or kwargs['method'] == defaultDense:
                return Batch_Float64DefaultDense(*args)
        if 'fptype' not in kwargs or kwargs['fptype'] == float32:
            if 'method' not in kwargs or kwargs['method'] == defaultDense:
                return Batch_Float32DefaultDense(*args)

        raise RuntimeError("No appropriate constructor found for Batch")


# This file is compatible with both classic and new-style classes.
